@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020 Tianjin KYLIN Information Technology Co., Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,6 @@
 #ifndef KSIMPLENM_H
 #define KSIMPLENM_H
 
-#include <sys/syslog.h>
-
 #include <QObject>
 #include <QProcess>
 #include <QDebug>
@@ -30,24 +28,37 @@ class KSimpleNM : public QObject
     Q_OBJECT
 public:
     explicit KSimpleNM(QObject *parent = nullptr);
+    ~KSimpleNM();
 
-    QProcess *runShellProcess = nullptr;
-    QString shellOutput;
-    int type;
-    bool isExecutingGetLanList = false;
-    bool isExecutingGetWifiList = false;
-    bool isUseOldLanSlist = false;
+//    QProcess *runProcessLan;
+//    QProcess *runProcessWifi;
+//    QProcess *runProcessConn;
+    QString shellOutputLan;
+    QString shellOutputWifi;
+    QString shellOutputConn;
+
+    bool isExecutingGetLanList = false; //是否正在执行获取有线网列表
+    bool isExecutingGetWifiList = false; //是否正在执行获取无线网列表
+    bool isUseOldLanSlist = false; //是否应该要用上一次获取的有线列表
+    bool isUseOldWifiSlist = false; //是否应该要用上一次获取的有线列表
 
     void execGetLanList();
-    void execGetWifiList();
+    void execGetWifiList(const QString& wname);
+    void execGetConnList();
 
 signals:
     void getLanListFinished(QStringList slist);
     void getWifiListFinished(QStringList slist);
+    void getConnListFinished(QStringList slist);
+    void requestRevalueUpdateWifi();
 
 public slots:
-    void readProcess();
-    void finishedProcess(int msg);
+//    void readProcessLan();
+//    void readProcessWifi();
+//    void readProcessConn();
+//    void finishedProcessLan(int msg);
+//    void finishedProcessWifi(int msg);
+//    void finishedProcessConn(int msg);
 };
 
 #endif // KSIMPLENM_H
