@@ -15,7 +15,6 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
  *
  */
-
 #include "kylin-network-interface.h"
 
 #include <netinet/in.h>
@@ -30,7 +29,6 @@
 #include <sys/syslog.h>
 #include <pwd.h>
 
-
 //获取网络接口名
 ifname *kylin_network_get_ifacename()
 {
@@ -122,7 +120,7 @@ conlist *kylin_network_get_conlist_info()
         fgets(StrLine,1024,fp);
 
         char *index=StrLine;
-        char conname[100];
+        char conname[256];
 
         //截取连接名称
         int num=0;
@@ -144,7 +142,7 @@ conlist *kylin_network_get_conlist_info()
         // printf("%s\n",clist[count].con_name);
 
         //截取连接类型
-        char type[100];
+        char type[256];
         for(index;*index!='\n';index++)
         {
             if(*index==' ')
@@ -200,7 +198,6 @@ activecon *kylin_network_get_activecon_info()
     char *path;
     asprintf(&path, "%s%s", tmpPrefix, name);
     int status = system(cmd);
-    //int status = system("nmcli connection show -active > /tmp/activecon.txt");
     if (status != 0)
         syslog(LOG_ERR, "execute 'nmcli connection show -active' in function 'kylin_network_get_activecon_info' failed");
     free(cmd);
@@ -242,7 +239,7 @@ activecon *kylin_network_get_activecon_info()
         fgets(StrLine,1024,fp);
 
         char *index=StrLine;
-        char conname[100];
+        char conname[256];
 
         //截取连接名称
         int num=0;
@@ -264,7 +261,7 @@ activecon *kylin_network_get_activecon_info()
         // printf("%s\n",activelist[count].con_name);
 
         //截取连接类型
-        char type[100];
+        char type[256];
         for(index;*index!='\n';index++)
         {
             if(*index==' ')
@@ -299,7 +296,7 @@ activecon *kylin_network_get_activecon_info()
 
         //截取连接所属设备
         char *index3=index2;
-        char dev[100];
+        char dev[256];
         for(index3;*index3!='\n';index3++)
         {
             if(*index3==' ')
@@ -334,9 +331,9 @@ activecon *kylin_network_get_activecon_info()
 //创建新的以太网连接
 void kylin_network_create_new_ethernet(char *con_name,char *if_name)
 {
-    char str[100];
+    char str[256];
     char *net_type="ethernet";
-    sprintf(str,"nmcli connection add con-name %s ifname %s type %s",con_name,if_name,net_type);
+    sprintf(str,"nmcli connection add con-name '%s' ifname '%s' type %s",con_name,if_name,net_type);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection add con-name' in function 'kylin_network_create_new_ethernet' failed");}
 }
@@ -354,53 +351,139 @@ void kylin_network_create_new_wifi(char *con_name, char *if_name)
 //删除以太网连接
 void kylin_network_del_ethernet_con(char *con_name)
 {
-    char str[100];
-    sprintf(str,"nmcli connection delete %s",con_name);
+    char str[256];
+    sprintf(str,"nmcli connection delete '%s'",con_name);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection delete' in function 'kylin_network_del_ethernet_con' failed");}
 }
 
 //设置动态分配ip
-void kylin_network_set_automethod(char *con_name)
+void kylin_network_set_automethod(char *con_uuid,char *con_name)
 {
-    char str[100];
+    char str[256];
     char *automethod="auto";
-    sprintf(str,"nmcli connection modify '%s' ipv4.method %s",con_name,automethod);
+    if (con_name && *con_name!='\0') {
+        sprintf(str,"nmcli connection modify '%s' connection.id %s ipv4.method %s ipv6.method %s",con_uuid,con_name,automethod,automethod);
+    }
+    else {
+        sprintf(str,"nmcli connection modify '%s' ipv4.method %s ipv6.method %s",con_uuid,automethod,automethod);
+    }
+
     int status = system(str);
-    if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_set_automethod' failed");}
+    if (status != 0) {
+        syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_set_automethod' failed");
+    } else {
+        syslog(LOG_ERR, "AUTO success: %s", str);
+    }
+}
+
+//设置动态分配ipv6地址
+void kylin_network_set_ipv6_automethod(char *con_name)
+{
+    char str[256];
+    char *automethod="auto";
+    sprintf(str,"nmcli connection modify '%s' ipv6.method %s ipv6.address ''",con_name,automethod);
+    int status = system(str);
+    if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_set_ipv6_automethod' failed");}
 }
 
 //设置手动分配ip
 void kylin_network_set_manualmethod(char *con_name,char *ip)
 {
-    char str[100];
+    char str[256];
     char *method="manual";
-    sprintf(str,"nmcli connection modify '%s' ipv4.method %s ipv4.address %s",con_name,method,ip);
+    sprintf(str,"nmcli connection modify '%s' ipv4.method %s ipv4.address '%s'",con_name,method,ip);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_set_manualmethod' failed");}
 }
 
+//设置手动分配ipv6地址
+void kylin_network_set_ipv6_manualmethod(char *con_name,char *ip)
+{
+    char str[256];
+    char *method="manual";
+    sprintf(str,"nmcli connection modify '%s' ipv6.method %s ipv6.address '%s'",con_name,method,ip);
+    int status = system(str);
+    if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_set_ipv6_manualmethod' failed");}
+}
+
 // 设置手动分配all
-void kylin_network_set_manualall(char *con_name, char *addr, char *mask, char *gateway, char *dns){
+void kylin_network_set_manualall(char *con_name, char *addr, char *mask, char *gateway, char *dns)
+{
     char str[200];
-    sprintf(str, "nmcli connection modify '%s' ipv4.method manual ipv4.address %s/%s ipv4.gateway %s ipv4.dns %s",
+    sprintf(str, "nmcli connection modify '%s' ipv4.method manual ipv4.address %s/%s ipv4.gateway '%s' ipv4.dns '%s'",
             con_name, addr, mask, gateway, dns);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_set_manualall' failed");}
 }
 
+void kylin_network_set(char *con_uuid ,char *con_name, char *ipv4_addr, char *mask, char *gateway, char *dns,char *ipv6_ip)
+{
+    char str[500] = {0};
+    char *head = "nmcli connection modify ";
+    strcpy(str, head);
+    strcat(str, con_uuid);
+    if (con_name && *con_name!='\0') {
+        char *name = " connection.id ";
+        strcat(str, name);
+        strcat(str, "'");
+        strcat(str, con_name);
+        strcat(str, "'");
+    }
+    if (ipv4_addr && *ipv4_addr!='\0') {
+        char *method = " ipv4.method manual";
+        strcat(str, method);
+        char *addr = " ipv4.address ";
+        strcat(str, addr);
+        strcat(str, ipv4_addr);
+        char *m = "/";
+        strcat(str, m);
+        strcat(str, mask);
+        if (gateway && *gateway!='\0') {
+            char *g = " ipv4.gateway ";
+            strcat(str, g);
+            strcat(str, gateway);
+        }
+        if (dns && *dns!='\0') {
+            char *d = " ipv4.dns ";
+            strcat(str, d);
+            strcat(str, dns);
+        }
+    } else {
+        char *method = " ipv4.method auto";
+        strcat(str, method);
+    }
+    if (ipv6_ip && *ipv6_ip!='\0') {
+        char *ip = " ipv6.method manual ipv6.address ";
+        strcat(str, ip);
+        strcat(str, ipv6_ip);
+        syslog(LOG_DEBUG, "[kylin-nm interface5] %s",str);
+    } else {
+        char *ip = " ipv6.method auto";
+        strcat(str, ip);
+        syslog(LOG_DEBUG, "[kylin-nm interface5] %s",str);
+    }
+    int status = system(str);
+    if (status != 0) {
+        syslog(LOG_ERR, "MANUALALL FAIL!");
+    } else {
+        syslog(LOG_DEBUG, "MANUALALL success: '%s'", str);
+    }
+}
+
+
 //设置是否自动连接
 void kylin_network_set_autoconnect(char *con_name,bool autocon)
 {
-    char str[100];
+    char str[256];
     if(autocon==false)
     {
         char *ac="no";
-        sprintf(str,"nmcli connection modify %s connection.autoconnect %s",con_name,ac);
+        sprintf(str,"nmcli connection modify '%s' connection.autoconnect %s",con_name,ac);
     }
     else{
         char *ac="yes";
-        sprintf(str,"nmcli connection modify %s connection.autoconnect %s",con_name,ac);
+        sprintf(str,"nmcli connection modify '%s' connection.autoconnect %s",con_name,ac);
     }
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_set_autoconnect' failed");}
@@ -409,8 +492,8 @@ void kylin_network_set_autoconnect(char *con_name,bool autocon)
 //修改ip
 void kylin_network_mod_ip(char *con_name,char *ip)
 {
-    char str[100];
-    sprintf(str,"nmcli connection modify %s ipv4.address %s",con_name,ip);
+    char str[256];
+    sprintf(str,"nmcli connection modify '%s' ipv4.address %s",con_name,ip);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_mod_ip' failed");}
 }
@@ -418,8 +501,8 @@ void kylin_network_mod_ip(char *con_name,char *ip)
 //修改网关
 void kylin_network_mod_gateway(char *con_name,char *gw)
 {
-    char str[100];
-    sprintf(str,"nmcli connection modify %s ipv4.gateway %s",con_name,gw);
+    char str[256];
+    sprintf(str,"nmcli connection modify '%s' ipv4.gateway %s",con_name,gw);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_mod_gateway' failed");}
 }
@@ -427,8 +510,8 @@ void kylin_network_mod_gateway(char *con_name,char *gw)
 //修改dns
 void kylin_network_mod_dns(char *con_name,char *dns)
 {
-    char str[100];
-    sprintf(str,"nmcli connection modify %s ipv4.dns %s",con_name,dns);
+    char str[256];
+    sprintf(str,"nmcli connection modify '%s' ipv4.dns %s",con_name,dns);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection modify' in function 'kylin_network_mod_dns' failed");}
 }
@@ -436,7 +519,7 @@ void kylin_network_mod_dns(char *con_name,char *dns)
 //连接以太网
 void kylin_network_set_con_up(char *con_name)
 {
-    char str[100];
+    char str[256];
     sprintf(str,"nmcli connection up '%s'",con_name);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection up' in function 'kylin_network_set_con_up' failed");}
@@ -445,7 +528,7 @@ void kylin_network_set_con_up(char *con_name)
 //断开以太网
 void kylin_network_set_con_down(char *con_name)
 {
-    char str[100];
+    char str[256];
     sprintf(str,"nmcli connection down '%s'",con_name);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli connection down' in function 'kylin_network_set_con_down' failed");}
@@ -454,7 +537,7 @@ void kylin_network_set_con_down(char *con_name)
 //连接wifi
 void kylin_network_set_wifi_up(char *con_name,char *passwd)
 {
-    char str[100];
+    char str[256];
     sprintf(str,"export LANG='en_US.UTF-8';export LANGUAGE='en_US';nmcli device wifi connect '%s' password '%s'", con_name,passwd);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli device wifi connect' in function 'kylin_network_set_wifi_up' failed");}
@@ -463,8 +546,8 @@ void kylin_network_set_wifi_up(char *con_name,char *passwd)
 //断开wifi连接
 void kylin_network_set_wifi_down(char *if_name)
 {
-    char str[100];
-    sprintf(str,"nmcli device disconnect '%s'",if_name);
+    char str[256];
+    snprintf(str,sizeof(str),"nmcli device disconnect '%s'",if_name);
     int status = system(str);
     if (status != 0){ syslog(LOG_ERR, "execute 'nmcli device disconnect' in function 'kylin_network_set_wifi_down' failed");}
 }
@@ -528,7 +611,7 @@ wifilist *kylin_network_get_wifilist_info()
             num++;
 
         }
-        char ssid[100];
+        char ssid[256];
         char *ssidindex=index-1;
         int ssidnum=0;
         for(ssidindex;*ssidindex==' ';ssidindex--)ssidnum++;
